@@ -1,6 +1,7 @@
 from mitosheet.utils import get_column_filter_type
 import pandas as pd
 import json
+import sys
 
 def get_column_describe(send, event, wsc):
     """
@@ -20,7 +21,12 @@ def get_column_describe(send, event, wsc):
         for index, row in describe.iteritems():
             # We turn all the items to strings, as some items are not valid JSON
             # e.g. some wacky numpy datatypes. This allows us to send all of this 
-            # to the front-end
+            # to the front-end.
+
+            # If the series is a number, round the statistics so they look good.
+            if get_column_filter_type(series) == 'number':
+                row = round(row, 2)
+
             describe_obj[index] = str(row)
 
         # We fill in some specific values that dont get filled by default
@@ -28,8 +34,8 @@ def get_column_describe(send, event, wsc):
 
         # NOTE: be careful adding things here, as we dont want to destroy performance 
         if get_column_filter_type(series) == 'number':
-            describe_obj['median'] = str(series.median())
-            describe_obj['sum'] = str(series.sum())
+            describe_obj['median'] = str(round(series.median(), 2))
+            describe_obj['sum'] = str(round(series.sum(), 2))
 
         send({
             'event': 'api_response',
