@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 """
 Contains all functions that can be used in a sheet that operate on
 numbers.
@@ -14,26 +15,24 @@ in more detail in docs/README.md.
 NOTE: This file is alphabetical order!
 """
 import functools
-from typing import Tuple, Union
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types.decorators import fill_nans, filter_nans, convert_args_to_series_type, convert_arg_to_series_type, handle_sheet_function_errors
-from mitosheet.sheet_functions.sheet_function_utils import try_extend_series_to_index, fill_series_with_one_index, fill_series_with_one_index
+from mitosheet.sheet_functions.types.decorators import filter_nans, convert_args_to_series_type, convert_arg_to_series_type, handle_sheet_function_errors
+from mitosheet.sheet_functions.sheet_function_utils import fill_series_list_to_max, fill_series_to_length
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
-def ABS(series: pd.Series) -> pd.Series:
+def ABS(series: pd.Series):
     """
     {
         "function": "ABS",
         "description": "Returns the absolute value of the passed number or series.",
-        "search_terms": ["abs", "absolute value"],
         "examples": [
             "ABS(-1.3)",
             "ABS(A)"
@@ -51,13 +50,12 @@ def ABS(series: pd.Series) -> pd.Series:
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type('float', 'skip', ('default', np.NaN))
-def AVG(*argv: pd.Series) -> pd.Series:
+@convert_args_to_series_type('number_series', 'skip', ('default', np.NaN))
+def AVG(*argv) -> pd.Series:
     """
     {
         "function": "AVG",
         "description": "Returns the numerical mean value of the passed numbers and series.",
-        "search_terms": ["avg", "average", "mean"],
         "examples": [
             "AVG(1, 2)",
             "AVG(A, B)",
@@ -76,7 +74,7 @@ def AVG(*argv: pd.Series) -> pd.Series:
     }
     """
     # Fill sum to the max length of any series
-    argv = fill_series_with_one_index(argv)
+    argv = fill_series_list_to_max(argv)
 
     arg_sum = functools.reduce((lambda x, y: x + y), argv) 
     return arg_sum / len(argv)
@@ -85,22 +83,21 @@ def AVG(*argv: pd.Series) -> pd.Series:
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
-def CORR(s1: pd.Series, s2: pd.Series) -> pd.Series:
+def CORR(s1, s2) -> pd.Series:
     """
     {
         "function": "CORR",
         "description": "Computes the correlation between two series, excluding missing values.",
-        "search_terms": ["corr", "correlation", "r^2"],
         "examples": [
             "=CORR(A, B)",
             "=CORR(B, A)"
@@ -118,81 +115,23 @@ def CORR(s1: pd.Series, s2: pd.Series) -> pd.Series:
     """
     corr = s1.corr(s2, method='pearson')
     return pd.Series(
-        [corr] * len(s1),
-        index=s1.index
+        [corr] * len(s1)
     )
 
-@handle_sheet_function_errors
-@filter_nans
-@convert_arg_to_series_type(
-    0,
-    'float',
-    'error',
-    ('default', np.NaN)
-)
-def FLOAT(series: pd.Series) -> pd.Series:
-    """
-    {
-        "function": "FLOAT",
-        "description": "Converts a string series to a float series. Any values that fail to convert will return NaN.",
-        "search_terms": ["number", "to number"],
-        "examples": [
-            "=FLOAT(Prices_string)",
-            "=FLOAT('123.123')"
-        ],
-        "syntax": "FLOAT(string_series)",
-        "syntax_elements": [{
-                "element": "string_series",
-                "description": "The series or string to convert to a float."
-            }
-        ]
-    }
-    """
-    return series
-
-@handle_sheet_function_errors
-@fill_nans(0, 0)
-@convert_arg_to_series_type(
-    0,
-    'int',
-    'error',
-    ('default', 0)
-)
-def INT(series: pd.Series) -> pd.Series:
-    """
-    {
-        "function": "INT",
-        "description": "Converts a string series to a int series. Any values that fail to convert will return 0.",
-        "search_terms": ["number", "to integer"],
-        "examples": [
-            "=INT(Prices_string)",
-            "=INT('123')"
-        ],
-        "syntax": "INT(string_series)",
-        "syntax_elements": [{
-                "element": "string_series",
-                "description": "The series or string to convert to a int."
-            }
-        ]
-    }
-    """
-    return series
-
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because kurtosis ignores NaN values
-def KURT(series: pd.Series) -> pd.Series:
+def KURT(series) -> pd.Series:
     """
     {
         "function": "KURT",
         "description": "Computes the unbiased kurtosis, a measure of tailedness, of a series, excluding missing values.",
-        "search_terms": ["kurtosis"],
         "examples": [
             "=KURT(A)",
             "=KURT(A * B)"
@@ -207,59 +146,19 @@ def KURT(series: pd.Series) -> pd.Series:
     """
     kurtosis = series.kurtosis()
     return pd.Series(
-        [kurtosis] * len(series),
-        index=series.index
+        [kurtosis] * len(series)
     )
 
 
 @handle_sheet_function_errors
 @filter_nans
 # NOTE: we set the default to -inf, so that we ignore values that fail to convert
-@convert_arg_to_series_type(
-    0,
-    'float',
-    'error',
-    ('default', np.NaN)
-)
-def LOG(series: pd.Series, base: Union[int, float]=None) -> pd.Series:
-    """
-    {
-        "function": "LOG",
-        "description": "Calculates the logarithm of the passed series with an optional base.",
-        "search_terms": ["log", "logarithm", "natural log"],
-        "examples": [
-            "LOG(e) = 1",
-            "LOG(100, 10) = 2"
-        ],
-        "syntax": "LOG(series, [base])",
-        "syntax_elements": [{
-                "element": "series",
-                "description": "The series to take the logarithm of."
-            },
-            {
-                "element": "base [OPTIONAL]",
-                "description": "The base of the logarithm to use. Defaults to the natural logarithm if no base is passed."
-            }
-        ]
-    }
-    """
-    if base is None:
-        return np.log(series)
-    # See here: https://stackoverflow.com/questions/25169297/numpy-logarithm-with-base-n
-    return np.log(series) / np.log(base)
-
-
-
-@handle_sheet_function_errors
-@filter_nans
-# NOTE: we set the default to -inf, so that we ignore values that fail to convert
-@convert_args_to_series_type('float', 'skip', ('default', float("-inf")))
-def MAX(*argv: pd.Series) -> pd.Series:
+@convert_args_to_series_type('number_series', 'skip', ('default', float("-inf")))
+def MAX(*argv) -> pd.Series:
     """
     {
         "function": "MAX",
         "description": "Returns the maximum value among the passed arguments.",
-        "search_terms": ["max", "maximum", "minimum"],
         "examples": [
             "MAX(10, 11)",
             "MAX(Old_Data, New_Data)"
@@ -277,20 +176,18 @@ def MAX(*argv: pd.Series) -> pd.Series:
     }
     """
     # We make a dataframe out of the series, and take the max between all the columns
-    argv = fill_series_with_one_index(argv)
     return pd.DataFrame(argv).max()
 
 
 @handle_sheet_function_errors
 @filter_nans
 # NOTE: we set the default to inf, so that we ignore values that fail to convert
-@convert_args_to_series_type('float', 'skip', ('default', float("inf")))
-def MIN(*argv: pd.Series) -> pd.Series:
+@convert_args_to_series_type('number_series', 'skip', ('default', float("inf")))
+def MIN(*argv) -> pd.Series:
     """
     {
         "function": "MIN",
         "description": "Returns the minimum value among the passed arguments.",
-        "search_terms": ["min", "minimum", "maximum"],
         "examples": [
             "MIN(10, 11)",
             "MIN(Old_Data, New_Data)"
@@ -308,19 +205,17 @@ def MIN(*argv: pd.Series) -> pd.Series:
     }
     """
     # We make a dataframe out of the series, and take the min between all the columns
-    argv = fill_series_with_one_index(argv)
     return pd.DataFrame(argv).min()
 
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type('float', 'skip', ('default', 1))
-def MULTIPLY(*argv: pd.Series) -> pd.Series:
+@convert_args_to_series_type('number_series', 'skip', ('default', 1))
+def MULTIPLY(*argv) -> pd.Series:
     """
     {
         "function": "MULTIPLY",
         "description": "Returns the product of two numbers.",
-        "search_terms": ["mulitply", "product"],
         "examples": [
             "MULTIPLY(2,3)",
             "MULTIPLY(A,3)"
@@ -338,7 +233,7 @@ def MULTIPLY(*argv: pd.Series) -> pd.Series:
     }
     """
     # We make sure all the series are the max length, so the * has something at every index
-    argv = fill_series_with_one_index(argv)
+    argv = fill_series_list_to_max(argv)
 
     return functools.reduce((lambda x, y: x * y), argv) 
 
@@ -347,13 +242,13 @@ def MULTIPLY(*argv: pd.Series) -> pd.Series:
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
-    'float',
+    'number_series',
     'skip',
     ('default', 1)
 )
@@ -362,7 +257,6 @@ def POWER(series, power):
     {
         "function": "POWER",
         "description": "The POWER function can be used to raise a number to a given power.",
-        "search_terms": ["power", "raise", "exponent", "square", "cube"],
         "examples": [
             "POWER(4, 1/2)",
             "POWER(Dose, 2)"
@@ -379,7 +273,7 @@ def POWER(series, power):
         ]
     }
     """
-    power = try_extend_series_to_index(power, series.index)
+    power = fill_series_to_length(power, len(series))
     return series.pow(power)
 
 
@@ -387,13 +281,13 @@ def POWER(series, power):
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
-    'float',
+    'number_series',
     'error',
     ('default', 2),
     optional=True
@@ -403,7 +297,6 @@ def ROUND(series, decimals=None):
     {
         "function": "ROUND",
         "description": "Rounds a number to a given number of decimals.",
-        "search_terms": ["round", "decimal", "integer"],
         "examples": [
             "ROUND(1.3)",
             "ROUND(A, 2)"
@@ -426,27 +319,25 @@ def ROUND(series, decimals=None):
         return series.round()
     
     # Otherwise, fill the decimals to length
-    decimals = try_extend_series_to_index(decimals, series.index)
+    decimals = fill_series_to_length(decimals, series.size)
 
     return pd.Series(
-        [round(num, dec) for num, dec in zip(series, decimals)],
-        index=series.index
+        [round(num, dec) for num, dec in zip(series, decimals)]
     )
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because skew ignores NaN values
-def SKEW(series: pd.Series) -> pd.Series:
+def SKEW(series) -> pd.Series:
     """
     {
         "function": "SKEW",
         "description": "Computes the skew of a series, excluding missing values.",
-        "search_terms": [],
         "examples": [
             "=SKEW(A)",
             "=SKEW(A * B)"
@@ -461,20 +352,18 @@ def SKEW(series: pd.Series) -> pd.Series:
     """
     skew = series.skew()
     return pd.Series(
-        [skew] * len(series),
-        index=series.index
+        [skew] * len(series)
     )
 
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type('float', 'skip', ('default', 0))
-def SUM(*argv: pd.Series) -> pd.Series:
+@convert_args_to_series_type('number_series', 'skip', ('default', 0))
+def SUM(*argv) -> pd.Series:
     """
     {
         "function": "SUM",
         "description": "Returns the sum of the given numbers and series.",
-        "search_terms": ["add"],
         "examples": [
             "SUM(10, 11)",
             "SUM(A, B, D, F)",
@@ -493,7 +382,7 @@ def SUM(*argv: pd.Series) -> pd.Series:
     }
     """
     # Fill sum to the max length of any series
-    argv = fill_series_with_one_index(argv)
+    argv = fill_series_list_to_max(argv)
 
     return functools.reduce((lambda x, y: x + y), argv) 
 
@@ -501,17 +390,16 @@ def SUM(*argv: pd.Series) -> pd.Series:
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because std ignores NaN values
-def STDEV(series: pd.Series) -> pd.Series:
+def STDEV(series) -> pd.Series:
     """
     {
         "function": "STDEV",
         "description": "Computes the standard deviation of a series, excluding missing values.",
-        "search_terms": ["standard", "deviation", "standard", "distribution"],
         "examples": [
             "=STDEV(A)",
             "=STDEV(A * B)"
@@ -526,8 +414,7 @@ def STDEV(series: pd.Series) -> pd.Series:
     """
     std = series.std()
     return pd.Series(
-        [std] * len(series),
-        index=series.index
+        [std] * len(series)
     )
 
 
@@ -536,16 +423,15 @@ def STDEV(series: pd.Series) -> pd.Series:
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
-def VALUE(series: pd.Series) -> pd.Series:
+def VALUE(series) -> pd.Series:
     """
     {
         "function": "VALUE",
         "description": "Converts a string series to a number series. Any values that fail to convert will return an NaN.",
-        "search_terms": ["number", "to number", "dtype", "convert", "parse"],
         "examples": [
             "=VALUE(A)",
             "=VALUE('123')"
@@ -562,48 +448,18 @@ def VALUE(series: pd.Series) -> pd.Series:
 
 
 @handle_sheet_function_errors
-@filter_nans
 @convert_arg_to_series_type(
     0,
-    'float',
-    'error',
-    ('default', np.NaN)
-)
-def EXP(series: pd.Series) -> pd.Series:
-    """
-    {
-        "function": "EXP",
-        "description": "Returns e, the base of the natural logarithm, raised to the power of passed series.",
-        "search_terms": ["exp", "exponent", "log", "natural log"],
-        "examples": [
-            "=EXP(data)",
-            "=EXP(A)"
-        ],
-        "syntax": "EXP(series)",
-        "syntax_elements": [{
-                "element": "series",
-                "description": "The series to raise e to."
-            }
-        ]
-    }
-    """
-    return np.exp(series)
-
-
-@handle_sheet_function_errors
-@convert_arg_to_series_type(
-    0,
-    'float',
+    'number_series',
     'error',
     ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because var ignores NaN values
-def VAR(series: pd.Series) -> pd.Series:
+def VAR(series) -> pd.Series:
     """
     {
         "function": "VAR",
         "description": "Computes the variance of a series, excluding missing values.",
-        "search_terms": ["variance"],
         "examples": [
             "=VAR(A)",
             "=VAR(A - B)"
@@ -618,8 +474,7 @@ def VAR(series: pd.Series) -> pd.Series:
     """
     var = series.var()
     return pd.Series(
-        [var] * len(series),
-        index=series.index
+        [var] * len(series)
     )
 
 # TODO: we should see if we can list these automatically!
@@ -627,11 +482,7 @@ NUMBER_FUNCTIONS = {
     'ABS': ABS,
     'AVG': AVG,
     'CORR': CORR,
-    'FLOAT': FLOAT,
-    'INT': INT,
-    'EXP': EXP,
     'KURT': KURT,
-    'LOG': LOG,
     'MAX': MAX,
     'MIN': MIN,
     'MULTIPLY': MULTIPLY,
