@@ -1,19 +1,18 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-from typing import Any
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 import pytest
 
-from mitosheet.errors import MitoError
-from mitosheet.parser import parse_formula, safe_replace, safe_contains
+from ..errors import EditError
+from ..parser import parse_formula, safe_replace, safe_contains
 
-CONSTANT_TEST_CASES: Any = [
+CONSTANT_TEST_CASES = [
     (
         '=100',
         'B',
-        ['B'],
         'df[\'B\'] = 100',
         set([]),
         set([])
@@ -21,7 +20,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=True',
         'B',
-        ['B'],
         'df[\'B\'] = True',
         set([]),
         set([])
@@ -29,7 +27,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=\'StringSingleQuotes\'',
         'B',
-        ['B'],
         'df[\'B\'] = \'StringSingleQuotes\'',
         set([]),
         set([])
@@ -37,7 +34,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=\"StringDoubleQuotes\"',
         'B',
-        ['B'],
         'df[\'B\'] = \"StringDoubleQuotes\"',
         set([]),
         set([])
@@ -45,7 +41,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=\"String Double Quotes\"',
         'B',
-        ['B'],
         'df[\'B\'] = \"String Double Quotes\"',
         set([]),
         set([])
@@ -53,7 +48,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=FUNC(\"String Double Quotes\")',
         'B',
-        ['B'],
         'df[\'B\'] = FUNC(\"String Double Quotes\")',
         set(['FUNC']),
         set([])
@@ -61,7 +55,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=FUNC(\"DIFF_FUNC(A)\")',
         'B',
-        ['B'],
         'df[\'B\'] = FUNC(\"DIFF_FUNC(A)\")',
         set(['FUNC']),
         set([])
@@ -69,7 +62,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=\"String One FUNC(A)\" + \"STRING TWO FUNC(A)\"',
         'B',
-        ['B'],
         'df[\'B\'] = \"String One FUNC(A)\" + \"STRING TWO FUNC(A)\"',
         set([]),
         set([])
@@ -77,7 +69,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=\'String One FUNC(A)\' + \'STRING TWO FUNC(A)\'',
         'B',
-        ['B'],
         'df[\'B\'] = \'String One FUNC(A)\' + \'STRING TWO FUNC(A)\'',
         set([]),
         set([])
@@ -85,7 +76,6 @@ CONSTANT_TEST_CASES: Any = [
     (
         '=FUNC1(\'String One FUNC(A)\') + FUNC2(\'STRING TWO FUNC(A)\')',
         'B',
-        ['B'],
         'df[\'B\'] = FUNC1(\'String One FUNC(A)\') + FUNC2(\'STRING TWO FUNC(A)\')',
         set(['FUNC1', 'FUNC2']),
         set([])
@@ -98,7 +88,6 @@ OPERATOR_TEST_CASES = [
     (
         '=A + B',
         'C',
-        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] + df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -107,7 +96,6 @@ OPERATOR_TEST_CASES = [
     (
         '=A - B',
         'C',
-        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] - df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -116,7 +104,6 @@ OPERATOR_TEST_CASES = [
     (
         '=A * B',
         'C',
-        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] * df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -125,7 +112,6 @@ OPERATOR_TEST_CASES = [
     (
         '=A / B',
         'C',
-        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] / df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -134,7 +120,6 @@ OPERATOR_TEST_CASES = [
     (
         '=AAA + BBB + CCC + DDD',
         'E',
-        ['AAA', 'BBB', 'CCC', 'DDD'],
         'df[\'E\'] = df[\'AAA\'] + df[\'BBB\'] + df[\'CCC\'] + df[\'DDD\']',
         set(),
         set(['AAA', 'BBB', 'CCC', 'DDD'])
@@ -143,7 +128,6 @@ OPERATOR_TEST_CASES = [
     (
         '=(A + B) / C + A * 100',
         'D',
-        ['A', 'B', 'C'],
         'df[\'D\'] = (df[\'A\'] + df[\'B\']) / df[\'C\'] + df[\'A\'] * 100',
         set(),
         set(['A', 'B', 'C'])
@@ -152,7 +136,6 @@ OPERATOR_TEST_CASES = [
     (
         '=FUNC(A + B / C + A * 100)',
         'D',
-        ['A', 'B', 'C'],
         'df[\'D\'] = FUNC(df[\'A\'] + df[\'B\'] / df[\'C\'] + df[\'A\'] * 100)',
         set(['FUNC']),
         set(['A', 'B', 'C'])
@@ -165,7 +148,6 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(A)',
         'B',
-        ['A', 'B', 'C'],
         'df[\'B\'] = FUNC(df[\'A\'])',
         set(['FUNC']),
         set(['A'])
@@ -174,7 +156,6 @@ FUNCTION_TEST_CASES = [
     (
         '=C(A)',
         'B',
-        ['A', 'B', 'C'],
         'df[\'B\'] = C(df[\'A\'])',
         set(['C']),
         set(['A'])
@@ -183,7 +164,6 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNCA(FUNCB(FUNCC(FUNCD(FUNCE(FUNCF(FUNCG(FUNCH(A))))))))',
         'B',
-        ['A', 'B', 'C'],
         'df[\'B\'] = FUNCA(FUNCB(FUNCC(FUNCD(FUNCE(FUNCF(FUNCG(FUNCH(df[\'A\']))))))))',
         set(['FUNCA', 'FUNCB', 'FUNCC', 'FUNCD', 'FUNCE', 'FUNCF', 'FUNCG', 'FUNCH']),
         set(['A'])
@@ -192,7 +172,6 @@ FUNCTION_TEST_CASES = [
     (
         '=RIGHT(A, LEN(B) - 10)',
         'C',
-        ['A', 'B', 'C'],
         'df[\'C\'] = RIGHT(df[\'A\'], LEN(df[\'B\']) - 10)',
         set(['RIGHT', 'LEN']),
         set(['A', 'B'])
@@ -201,7 +180,6 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(A, FUNC(B, FUNC(C)))',
         'D',
-        ['A', 'B', 'C'],
         'df[\'D\'] = FUNC(df[\'A\'], FUNC(df[\'B\'], FUNC(df[\'C\'])))',
         set(['FUNC']),
         set(['A', 'B', 'C'])
@@ -210,7 +188,6 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(A, B, C, D, E, F, G, H, I)',
         'J',
-        ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I'],
         'df[\'J\'] = FUNC(df[\'A\'], df[\'B\'], df[\'C\'], df[\'D\'], df[\'E\'], df[\'F\'], df[\'G\'], df[\'H\'], df[\'I\'])',
         set(['FUNC']),
         set(['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I'])
@@ -219,110 +196,26 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(column1, column2)',
         'J',
-        ['column1', 'column2', 'J'],
         'df[\'J\'] = FUNC(df[\'column1\'], df[\'column2\'])',
         set(['FUNC']),
         set(['column1', 'column2'])
     ),
-    # Test references to columns with spaces
+    # Test references to columns with underscores
     (
-        '=FUNC(column 1, column 2)',
+        '=FUNC(column_1, column_2)',
         'J',
-        ['column 1', 'column 2', 'J'],
-        'df[\'J\'] = FUNC(df[\'column 1\'], df[\'column 2\'])',
+        'df[\'J\'] = FUNC(df[\'column_1\'], df[\'column_2\'])',
         set(['FUNC']),
-        set(['column 1', 'column 2'])
+        set(['column_1', 'column_2'])
     ),
-    # Test references to columns that are numbers
+    # Test references to columns that are lookups
     (
-        '=FUNC(123, 456)',
+        '=FUNC(LOOKUP, XLOOKUP, VLOOKUP, HLOOKUP)',
         'J',
-        [123, 456, 'J'],
-        'df[\'J\'] = FUNC(df[123], df[456])',
+        'df[\'J\'] = FUNC(df[\'LOOKUP\'], df[\'XLOOKUP\'], df[\'VLOOKUP\'], df[\'HLOOKUP\'])',
         set(['FUNC']),
-        set([123, 456])
-    ),
-    # Test references to columns that are numbers and are also strings
-    (
-        '=FUNC(123, 456, abc)',
-        'J',
-        ['abc', 456, 123, "J"],
-        'df[\'J\'] = FUNC(df[123], df[456], df[\'abc\'])',
-        set(['FUNC']),
-        set([123, 456, 'abc'])
-    ),
-    # Test references to strings that has a single quotes in it
-    (
-        '=FUNC(this is a string \' that has a quote, 456, abc)',
-        'J',
-        ['abc', 456, 'this is a string \' that has a quote', "J"],
-        'df[\'J\'] = FUNC(df[\'this is a string \' that has a quote\'], df[456], df[\'abc\'])',
-        set(['FUNC']),
-        set(['abc', 456, 'this is a string \' that has a quote'])
-    ),
-    # Test references to strings that have mulitple quotes
-    (
-        '=FUNC(this is a string \'test\' that has a quote, 456, abc)',
-        'J',
-        ['abc', 456, 'this is a string \'test\' that has a quote', "J"],
-        'df[\'J\'] = FUNC(df[\'this is a string \'test\' that has a quote\'], df[456], df[\'abc\'])',
-        set(['FUNC']),
-        set(['abc', 456, 'this is a string \'test\' that has a quote'])
-    ),
-    # Test references to a string in quotes, but is a column header
-    (
-        '=FUNC("column")',
-        'J',
-        ["\"column\"", "J"],
-        'df[\'J\'] = FUNC(df[\'"column"\'])',
-        set(['FUNC']),
-        set(["\"column\""])
-    ),
-    # Test references to a quote that is covered by a column header
-    (
-        '=FUNC("this is a string")',
-        'J',
-        ["string", "J"],
-        'df[\'J\'] = FUNC("this is a string")',
-        set(['FUNC']),
-        set([])
-    ),
-    # Test references a boolean column
-    (
-        '=true + false',
-        'A',
-        [True, False],
-        'df[\'A\'] = df[True] + df[False]',
-        set([]),
-        set([True, False])
-    ),
-    # Test references a multi-index header
-    (
-        '=Height, min',
-        'Name',
-        [('Name', ''), ('Height', 'min')],
-        'df[\'Name\'] = df[(\'Height\', \'min\')]',
-        set([]),
-        set([('Height', 'min')])
-    ),
-    # Test references a multi-index header in a function
-    (
-        '=FUNC(Height, min)',
-        'Name',
-        [('Name', ''), ('Height', 'min')],
-        'df[\'Name\'] = FUNC(df[(\'Height\', \'min\')])',
-        set(['FUNC']),
-        set([('Height', 'min')])
-    ),
-    # Test references a multi-index header with an empty second item
-    (
-        '=FUNC(Name)',
-        'Name',
-        [('Name', ''), ('Height', 'min')],
-        'df[\'Name\'] = FUNC(df[(\'Name\', \'\')])',
-        set(['FUNC']),
-        set([('Name', '')])
-    ),
+        set(['LOOKUP', 'XLOOKUP', 'VLOOKUP', 'HLOOKUP'])
+    ) 
 ]
 
 
@@ -336,9 +229,9 @@ Order of params is: formula, address, python_code, functions, columns
 See documentation here: https://docs.pytest.org/en/latest/parametrize.html#parametrize-basics
 """
 PARSE_TESTS = CONSTANT_TEST_CASES + OPERATOR_TEST_CASES + FUNCTION_TEST_CASES
-@pytest.mark.parametrize("formula,column_header,column_headers,python_code,functions,columns", PARSE_TESTS)
-def test_parse(formula, column_header, column_headers, python_code, functions, columns):
-    assert parse_formula(formula, column_header, column_headers) == \
+@pytest.mark.parametrize("formula,address,python_code,functions,columns", PARSE_TESTS)
+def test_parse(formula, address, python_code, functions, columns):
+    assert parse_formula(formula, address) == \
         (
             python_code, 
             functions, 
@@ -352,37 +245,37 @@ PARSE_TEST_ERRORS = [
     ('=HLOOKUP(100, A)', 'B', 'invalid_formula_error', 'HLOOKUP'),
     ('=XLOOKUP(100, A)', 'B', 'invalid_formula_error', 'XLOOKUP'),
     ('=A <> 100', 'B', 'invalid_formula_error', '<>'),
-    ('=SUM(A', 'B', 'invalid_formula_error', 'parentheses'),
 ]
 @pytest.mark.parametrize("formula, address, error_type, to_fix_substr", PARSE_TEST_ERRORS)
 def test_parse_errors(formula, address, error_type, to_fix_substr):
-    with pytest.raises(MitoError) as e_info:
-        parse_formula(formula, address, ['A', 'B'])
+    with pytest.raises(EditError) as e_info:
+        parse_formula(formula, address)
     assert e_info.value.type_ == error_type
     if to_fix_substr is not None:
         assert to_fix_substr in e_info.value.to_fix
 
 
 SAFE_REPLACE_TESTS = [
-    ('=A', 'A', 'B', ['A', 'B'], '=B'),
-    ('=A + A', 'A', 'B', ['A', 'B'], '=B + B'),
-    ('=A + B', 'A', 'B', ['A', 'B'], '=B + B'),
-    ('=A + B + A', 'A', 'B', ['A', 'B'], '=B + B + B'),
-    ('=This is a test', 'test', 'B', ['This is a test'], '=This is a test'),
-    ('="test with spaces"', 'test with spaces', 'B', ['test with spaces'], '="test with spaces"'),
-    ('=A + B + \"A\"', 'A', 'B', ['A', 'B'], '=B + B + \"A\"'),
-    ('=A + B + \'A\'', 'A', 'B', ['A', 'B'], '=B + B + \'A\''),
-    ('=A + B + \'A\'', 'A', 'B', ['A', 'B'], '=B + B + \'A\''),
-    ('=FUNC(A, B, A) + TEST(FUNC(A, \'A\', \'B\')) + \'A\'', 'A', 'B', ['A', 'B'], '=FUNC(B, B, B) + TEST(FUNC(B, \'A\', \'B\')) + \'A\''),
-    ('=APPLE(A, B, A) + AARON(AAA(A, \'A\', \'B\')) + \'A\'', 'A', 'B', ['A', 'B'], '=APPLE(B, B, B) + AARON(AAA(B, \'A\', \'B\')) + \'A\''),
+    ('=A', 'A', 'B', '=B'),
+    ('=A + A', 'A', 'B', '=B + B'),
+    ('=A + B', 'A', 'B', '=B + B'),
+    ('=A + B + A', 'A', 'B', '=B + B + B'),
+    ('=A + B + \"A\"', 'A', 'B', '=B + B + \"A\"'),
+    ('=A + B + \'A\'', 'A', 'B', '=B + B + \'A\''),
+    ('=A + B + \'A\'', 'A', 'B', '=B + B + \'A\''),
+    ('=FUNC(A, B, A) + TEST(FUNC(A, \'A\', \'B\')) + \'A\'', 'A', 'B', '=FUNC(B, B, B) + TEST(FUNC(B, \'A\', \'B\')) + \'A\''),
+    ('=APPLE(A, B, A) + AARON(AAA(A, \'A\', \'B\')) + \'A\'', 'A', 'B', '=APPLE(B, B, B) + AARON(AAA(B, \'A\', \'B\')) + \'A\''),
 ]
 
-@pytest.mark.parametrize('formula,old_column_header,new_column_header,column_headers,new_formula', SAFE_REPLACE_TESTS)
-def test_safe_replace(formula, old_column_header, new_column_header, column_headers, new_formula):
-    assert safe_replace(formula, old_column_header, new_column_header, column_headers) == new_formula
+@pytest.mark.parametrize('formula,old_text,new_text,new_formula', SAFE_REPLACE_TESTS)
+def test_safe_replace(formula, old_text, new_text, new_formula):
+    assert safe_replace(formula, old_text, new_text) == new_formula
 
 
 SAFE_CONTAINS_TESTS = [
+    ('=A', 'A', True),
+    ('=A + B', 'B', True),
+    ('=A + "B"', 'B', False),
     ('=A & "B"', '&', True),
     ('=A - +  "&"', '&', False),
     ('=A - +  \'&\'', '&', False),
@@ -390,4 +283,4 @@ SAFE_CONTAINS_TESTS = [
 
 @pytest.mark.parametrize('formula,substring,contains', SAFE_CONTAINS_TESTS)
 def test_safe_contains(formula, substring, contains):
-    assert safe_contains(formula, substring, ['A', 'B']) == contains
\ No newline at end of file
+    assert safe_contains(formula, substring) == contains
\ No newline at end of file
