@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 """
 After reading in the arguments passed to the frontend,
 this update figures out which of them were dataframes
@@ -10,7 +11,7 @@ and which of them were file paths, and updates the
 df names in the steps properly.
 """
 
-from mitosheet.utils import get_valid_dataframe_names
+from mitosheet.steps.import_steps.simple_import import get_dataframe_names
 
 ARGS_UPDATE_EVENT = 'args_update'
 ARGS_UPDATE_PARAMS = ['args']
@@ -26,11 +27,11 @@ def is_str_df_name(arg):
     return arg.startswith('\'') or arg.startswith('\"')
 
 def execute_args_update(
-        steps_manager,
+        wsc,
         args
     ):
     """
-    Changes the df_names in the current step from information
+    Changes the df_names in the current step - from information
     from the frontend.
 
     The information from the frontend is a list of all the parameters
@@ -42,7 +43,6 @@ def execute_args_update(
     names we turn it into _must be the same as the names transpiled_
     by the preprocess read file paths preprocessing step!
     """
-
     # We send / don't do anything with empty df_name updates
     # as we want the sheet to refresh in this case with no errors
     if len(args) > 0:
@@ -55,7 +55,7 @@ def execute_args_update(
         # with the same name as the the result of the return of this function,
         # but we ignore this for now. E.g. mitosheet.sheet('df1.csv', 'df1_csv') 
         # will cause only variable to exist.
-        str_df_names = get_valid_dataframe_names([], str_args)
+        str_df_names = get_dataframe_names(str_args, [])
 
         final_names = []
         used_str_df_names = 0
@@ -69,8 +69,8 @@ def execute_args_update(
         # Finially, we don't add more names than there are dataframes (as this is clearly
         # nonsense), and thus this allows us to filter out Nones that are passed at the 
         # end of the arguments (not creating phantom tabs that cannot be clicked)
-        steps_manager.curr_step.post_state.df_names = final_names[:len(steps_manager.curr_step.dfs)]
-    
+        wsc.curr_step['df_names'] = final_names[:len(wsc.curr_step['dfs'])]
+
 
 ARGS_UPDATE = {
     'event_type': ARGS_UPDATE_EVENT,
